@@ -16,6 +16,8 @@
 
 
 
+#include "config.h"
+
 #include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -544,7 +546,9 @@ auth_user ( POP *p, char *password, struct passwd *pw, char *err_buf, int err_le
 #    endif  /* DECLARED_AUTH_USER */
 
 
-#  endif /* USE_PAM */
+#else /* USE_PAM is defined */
+#error "No poppassd block for use with PAM"
+#  endif /* not USE_PAM */
 
 
 /*------------------------------------- not SPEC_POP_AUTH */
