@@ -12,6 +12,11 @@
  *
  * Revisions:
  *
+ *     06/10/08  [rcg]
+ *              - Patch from Chavalam Ravindranath to fix crash
+ *                dereferencing parameter 'msg' in function
+ *                PAM_qpopper_conv.
+ *
  *     04/22/05  [rcg]
  *              - Use generic auth error msg and sleep in more cases
  *
@@ -438,8 +443,8 @@ PAM_qpopper_conv ( int                        num_msg,
 
     for ( replies = 0; replies < num_msg; replies++ ) {
         DEBUG_LOG2 ( p, "PAM_qpopper_conv: msg_style[%i]=%i", 
-                     replies, msg[replies]->msg_style );
-        switch (msg[replies]->msg_style) {
+                     replies, (*msg)[replies].msg_style );
+        switch ( (*msg)[replies].msg_style ) {
         
         case PAM_PROMPT_ECHO_ON: /* assume it wants user name */
             reply[replies].resp_retcode = PAM_SUCCESS;
@@ -505,7 +510,7 @@ struct passwd *pw;
                             pam_strerror(NULL, erc), erc ) );
     }
     pamerror = pam_set_item ( pamh, PAM_TTY, p->ipaddr );
-    DEBUG_LOG1 ( p, "pam_set_item returned %i", pamerror );
+    DEBUG_LOG1 ( p, "pam_set_item (TTY) returned %i", pamerror );
     if ( pamerror != PAM_SUCCESS ) {
         pop_log ( p, POP_NOTICE, HERE,
                   "Error setting pam item TTY: %s (%i)", 
@@ -513,7 +518,7 @@ struct passwd *pw;
     }
 
     pamerror = pam_set_item ( pamh, PAM_RHOST, p->client );
-    DEBUG_LOG1 ( p, "pam_set_item returned %i", pamerror );
+    DEBUG_LOG1 ( p, "pam_set_item (RHOST) returned %i", pamerror );
     if ( pamerror != PAM_SUCCESS ) {
         pop_log ( p, POP_NOTICE, HERE,
                   "Error setting pam item RHOST: %s (%i)", 
@@ -521,7 +526,6 @@ struct passwd *pw;
     }
     pamerror = pam_authenticate ( pamh, 0 );
 
-
     DEBUG_LOG2 ( p, "pam_authenticate returned %i; gp_errcode=%i", 
                  pamerror, gp_errcode );
     if ( ( gp_errcode != 0 ) || ( pamerror != PAM_SUCCESS ) ) {
@@ -533,7 +537,7 @@ struct passwd *pw;
                             p->user, errmsg, erc ) );
     }
     pamerror = pam_setcred ( pamh, PAM_ESTABLISH_CRED );
-    DEBUG_LOG1 ( p, "pam_setcred returned %i", pamerror );
+    DEBUG_LOG1 ( p, "pam_setcred (ESTABLISH_CRED) returned %i", pamerror );
     if ( pamerror != PAM_SUCCESS ) {
         errmsg = pam_strerror ( pamh, pamerror );
         pam_end ( pamh, 0 );
@@ -562,7 +566,7 @@ struct passwd *pw;
     }
     
     pamerror = pam_setcred ( pamh, PAM_DELETE_CRED );
-    DEBUG_LOG1 ( p, "pam_setcred returned %i", pamerror );
+    DEBUG_LOG1 ( p, "pam_setcred (DELETE_CRED) returned %i", pamerror );
     pam_end ( pamh, PAM_SUCCESS );
 
     return POP_SUCCESS;
