@@ -6,13 +6,17 @@
  
  
 /*
- * Copyright (c) 2001 Qualcomm Incorporated.  All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  *
  * Revisions:
  *
+ * 08/13/01  [dts]
+ *          - set hangup = TRUE in pop_write_now() and pop_write_flush()
+ *            in the event of an I/O error.
+ *
  * 04/22/01  [rcg]
  *          - pop_write_chunk() now correctly handles chunks longer
  *            than the output buffer size.
@@ -89,6 +93,10 @@
 #include "mmangle/mangle.h"
 #include "snprintf.c"
 
+#if       HAVE_TIME_H
+#  include <time.h>
+#endif /* HAVE_TIME_H */
+
 
 #ifdef    TRACE_MSG_BODY
 #  define TRACING_BODY  1
@@ -687,6 +695,7 @@ pop_write_flush ( POP *p )
                       "%s (%d)",
                       p->user, p->client, p->ipaddr, STRERROR(e), e );
         }
+        hangup = TRUE;
     } /* flush failed */
 #ifdef    _DEBUG
     else
@@ -728,6 +737,7 @@ pop_write_now ( POP *p, char *buffer, int length )
                     "I/O error writing to client %s at %s [%s]: %s (%d)",
                     p->user, p->client, p->ipaddr, STRERROR(e), e );
         }
+        hangup = TRUE;
     } /* write failed */
 }
 
